# Version History

## 1.0 2025-10-21

* The first official release.
* The only change from 0.10.1 is that it now requires base_loom_server 1.0.

## 0.10.1 2025-10-03

* Fix an incorrect dependency in pyproject.toml.

## 0.10 2025-10-02

* Simplify BaseLoomServer slightly.
  This change requires base_loom_server 0.34.

## 0.9.1 2025-07-07

Internal changes:

* Improve the mypy configuration to be pickier.
* Switch to ruff for checking and formatting.
* Update the code accordingly.

## 0.9 2025-07-05

* Update for base_loom_server 0.26, which is required.

## 0.8 2025-06-26

* Update for base_loom_server 0.24.
  (base_loom_server 0.19 will still work, but two unit tests will fail.)

## 0.7 2025-06-03

* Update for base_loom_server 0.19, which adds a Settings panel.
* Add this version history.

## 0.6.3 2025-03-31

Minor documentation fixes.

## 0.6.2 2025-03-18

Internal changes.

## 0.6.1 2025-03-15

Internal changes.

## 0.6.0 2025-03-14

The first release.
